# Generated by Django 3.2.4 on 2021-08-23 14:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0011_auto_20210726_2047"),
        ("mailer_integration", "0004_auto_20210823_1424"),
    ]

    operations = [
        migrations.AlterField(
            model_name="mailingpreferences",
            name="email",
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.CASCADE, to="core.email"
            ),
        ),
    ]
