# Generated by Django 3.2.5 on 2021-07-26 13:47

from django.db import migrations, models

import basxconnect.core.models.persons


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0010_auto_20210523_1140"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicallegalperson",
            name="personnumber",
            field=models.CharField(
                db_index=True,
                default=basxconnect.core.models.persons.random_personid,
                max_length=255,
                verbose_name="Person number",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnaturalperson",
            name="personnumber",
            field=models.CharField(
                db_index=True,
                default=basxconnect.core.models.persons.random_personid,
                max_length=255,
                verbose_name="Person number",
            ),
        ),
        migrations.AlterField(
            model_name="historicalperson",
            name="personnumber",
            field=models.CharField(
                db_index=True,
                default=basxconnect.core.models.persons.random_personid,
                max_length=255,
                verbose_name="Person number",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpersonassociation",
            name="personnumber",
            field=models.CharField(
                db_index=True,
                default=basxconnect.core.models.persons.random_personid,
                max_length=255,
                verbose_name="Person number",
            ),
        ),
        migrations.AlterField(
            model_name="person",
            name="personnumber",
            field=models.CharField(
                default=basxconnect.core.models.persons.random_personid,
                max_length=255,
                unique=True,
                verbose_name="Person number",
            ),
        ),
    ]
