# Generated by Django 3.2.5 on 2021-10-04 10:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0018_term_slug"),
    ]

    operations = [
        migrations.AlterField(
            model_name="term",
            name="slug",
            field=models.CharField(
                max_length=255, unique=True, verbose_name="Slug", blank=True
            ),
        ),
    ]
