# Generated by Django 3.2.5 on 2021-09-28 04:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0011_auto_20210726_2047"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnaturalperson",
            name="autogenerate_displayname",
            field=models.BooleanField(
                default=True, verbose_name="Autogenerate Display Name"
            ),
        ),
        migrations.AddField(
            model_name="naturalperson",
            name="autogenerate_displayname",
            field=models.BooleanField(
                default=True, verbose_name="Autogenerate Display Name"
            ),
        ),
    ]
