# Generated by Django 3.2.4 on 2021-11-19 08:30

import django.db.models.deletion
import django.db.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mailer_integration", "0011_invalidperson_newperson_synchronizationresult"),
    ]

    operations = [
        migrations.CreateModel(
            name="SynchronizationPerson",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("email", models.CharField(max_length=100)),
                (
                    "first_name",
                    models.CharField(
                        blank=True, max_length=255, verbose_name="First Name"
                    ),
                ),
                (
                    "last_name",
                    models.CharField(
                        blank=True, max_length=255, verbose_name="Last Name"
                    ),
                ),
                (
                    "successfully_added",
                    models.BooleanField(
                        verbose_name=django.db.models.fields.BooleanField
                    ),
                ),
                (
                    "sync_result",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="persons",
                        to="mailer_integration.synchronizationresult",
                    ),
                ),
            ],
        ),
        migrations.RemoveField(
            model_name="newperson",
            name="sync_result",
        ),
        migrations.DeleteModel(
            name="InvalidPerson",
        ),
        migrations.DeleteModel(
            name="NewPerson",
        ),
    ]
