# Generated by Django 3.2.5 on 2021-09-28 07:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0012_auto_20210928_1158"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="Category",
            new_name="Vocabulary",
        ),
        migrations.AlterModelOptions(
            name="vocabulary",
            options={
                "ordering": ["name"],
                "verbose_name": "Vocabulary",
                "verbose_name_plural": "Vocabularies",
            },
        ),
    ]
